@@ -1,5 +1,5 @@
 ;;; Lepton EDA library - Scheme API
-;;; Copyright (C) 2020-2021 Lepton EDA Contributors
+;;; Copyright (C) 2020-2022 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -54,9 +54,13 @@
             glist-data
             glist-next
             glist-prev
+            glist->list
 
             ;; Foreign functions.
+            edascm_current_toplevel
             edascm_c_current_toplevel
+            edascm_from_toplevel
+            edascm_with_toplevel
             edascm_is_object
             edascm_from_object
             edascm_to_object
@@ -139,6 +143,8 @@
             lepton_export_settings_set_format
             lepton_export_settings_set_outfile
 
+            lepton_list_get_glist
+
             lepton_object_get_attached_to
             lepton_object_set_attached_to
             lepton_object_get_attribs
@@ -158,6 +164,7 @@
             lepton_object_set_parent
             lepton_object_get_selectable
             lepton_object_set_selectable
+            lepton_object_get_selected
             lepton_object_get_stroke_cap_type
             lepton_object_set_stroke_cap_type
             lepton_object_get_stroke_type
@@ -354,6 +361,9 @@
             s_conn_return_others
             s_conn_update_object
 
+            o_selection_add
+
+            lepton_toplevel_new
             lepton_toplevel_get_page_current
             lepton_toplevel_get_pages
 
@@ -374,7 +384,9 @@
 
             o_selection_remove
 
-            o_read_buffer))
+            o_read_buffer
+
+            lepton_coord_snap))
 
 ;;; Helper to check if result of C function is TRUE (non-zero).
 (define true? (negate zero?))
@@ -433,6 +445,14 @@
       ((data next prev) data)
       (_ (error "Wrong Glist in glist-data()")))))
 
+(define (glist->list gls convert-func)
+  (let loop ((gls gls)
+             (ls '()))
+    (if (null-pointer? gls)
+        (reverse ls)
+        (loop (glist-next gls)
+              (cons (convert-func (glist-data gls)) ls)))))
+
 ;;; Basic lepton initialisation function.
 (define-lff liblepton_init void '())
 (define-lff edascm_init void '())
@@ -451,7 +471,12 @@
 (define-lff s_clib_get_symbol_by_name '* '(*))
 (define-lff s_clib_init void '())
 (define-lff s_clib_symbol_get_filename '* '(*))
+
+;;; o_selection.c
+(define-lff o_selection_add void '(* *))
+
 ;;; toplevel.c
+(define-lff lepton_toplevel_new '* '())
 (define-lff lepton_toplevel_get_page_current '* '(*))
 (define-lff lepton_toplevel_get_pages '* '(*))
 ;;; g_rc.c
@@ -519,7 +544,10 @@
 (define-lff eda_renderer_set_color_map void '(* *))
 
 ;;; scheme_smob.c
+(define-lff edascm_current_toplevel '* '())
 (define-lff edascm_c_current_toplevel '* '())
+(define-lff edascm_from_toplevel '* '(*))
+(define-lff edascm_with_toplevel '* '(* *))
 (define-lff edascm_is_object int '(*))
 (define-lff edascm_is_page int '(*))
 (define-lff edascm_from_object '* '(*))
@@ -527,6 +555,9 @@
 (define-lff edascm_from_page '* '(*))
 (define-lff edascm_to_page '* '(*))
 
+;;; list.c
+(define-lff lepton_list_get_glist '* '(*))
+
 ;;; object.c
 (define-lff lepton_object_get_attached_to '* '(*))
 (define-lff lepton_object_set_attached_to void '(* *))
@@ -547,6 +578,7 @@
 (define-lff lepton_object_set_parent void '(* *))
 (define-lff lepton_object_get_selectable int '(*))
 (define-lff lepton_object_set_selectable void (list '* int))
+(define-lff lepton_object_get_selected int '(*))
 (define-lff lepton_object_get_stroke_cap_type int '(*))
 (define-lff lepton_object_set_stroke_cap_type void (list '* int))
 (define-lff lepton_object_get_stroke_type int '(*))
@@ -773,8 +805,11 @@
 (define-lff lepton_export_settings_set_format void '(*))
 (define-lff lepton_export_settings_set_outfile void '(*))
 
+(define-lff lepton_coord_snap int (list int int))
+
 (define (c-string-array->list pointer)
-  "Returns a list of search directories for system data."
+  "Returns a list of strings from the array of C strings pointed to
+by POINTER."
   (let loop ((num 0)
              (ls '()))
     (let ((string-pointer
