@@ -1,9 +1,12 @@
 (define-module (lepton m4))
+(define-public %lepton-docdir "/usr/local/share/doc/lepton-eda")
+(define-public %lepton-localedir "/usr/local/share/locale")
+(define-public %lepton-bindir "/usr/local/bin")
 (define-public %m4-use-cygwin #f)
 (define-public %m4-use-gtk3 #f)
-(define-public %m4-liblepton-major 10)
-(define-public %m4-libleptonattrib-major 4)
-(define-public %m4-libleptongui-major 4)
+(define-public %m4-liblepton-major 11)
+(define-public %m4-libleptonattrib-major 5)
+(define-public %m4-libleptongui-major 5)
 (define-public %m4-liblepton-gettext-domain "liblepton")
 (define-public %ldconfig-libglib "")
 (define-public %ldconfig-libgobject "")
