@@ -2,7 +2,7 @@
 ;; Scheme API
 ;; Copyright (C) 2013 Peter Brett <peter@peter-b.co.uk>
 ;; Copyright (C) 2013-2015 gEDA Contributors
-;; Copyright (C) 2017-2020 Lepton EDA Contributors
+;; Copyright (C) 2017-2022 Lepton EDA Contributors
 ;;
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -32,7 +32,8 @@
   #:use-module (schematic action)
   #:use-module (schematic core gettext)
   #:use-module (schematic ffi)
-  #:use-module (schematic gschemdoc)
+  #:use-module (schematic doc)
+  #:use-module (schematic gui keymap)
   #:use-module (schematic hook)
   #:use-module (schematic menu)
   #:use-module (schematic repl)
@@ -101,7 +102,8 @@
 
   (x_window_open_page
    (x_window_create_main new-window
-                         (make-main-menu new-window))
+                         (make-main-menu new-window)
+                         *process-key-event)
    %null-pointer))
 
 (define-action-public (&file-new-window #:label (G_ "New Window") #:icon "window-new")
